@@ -7,7 +7,7 @@ class SiteConfiguration(SingletonModel):
     site_name = models.CharField(max_length=255, default='Default Config')
 
     def __unicode__(self):
-        return u"Site Configuration"
+        return "Site Configuration"
 
     class Meta:
         verbose_name = "Site Configuration"
